import { useMemo } from 'react';
import { ColumnDef } from '@tanstack/react-table';
import dayjs from 'dayjs';
import relativeTime from 'dayjs/plugin/relativeTime';
import { DataTable } from '@/components/DataTable/StatusDataTable';
import { DataTableColumnHeader } from '@/components/DataTable/DataTableColumnHeader';
import Error from '@/pages/Errors';
import DataTableShimmer from '@/components/DataTable/DataTableShimmer';
import { toast } from 'sonner';
import useTitle from '@/hooks/useTitle';
import {
  useDeleteCourseMutation,
  useGetCourseByInstructorQuery,
} from '@/app/backend/endpoints/courses';
import { Settings2, Trash2 } from 'lucide-react';
import AlertDialogDemo from '@/components/AlertDialogDemo';
import { useNavigate } from 'react-router-dom';
import useUser from '@/hooks/useUser';
import { Button } from '@/components/ui/button';

dayjs.extend(relativeTime);

export default function MarketCourses() {
  useTitle('My-Courses');
  const { user } = useUser();
  const {
    data: dataWrap,
    isLoading,
    isError,
    isFetching,
  } = useGetCourseByInstructorQuery((user as InstructionalDesigner)?.user_id);
  // console.log(dataWrap);

  const data = dataWrap?.data;
  const navigate = useNavigate();
  const [deleteCourse, { isLoading: isDeleting }] = useDeleteCourseMutation();
  const columns: ColumnDef<CEMarketCourseI>[] = useMemo(
    () => [
      {
        accessorKey: 'status',
        header: ({ column }) => (
          <DataTableColumnHeader
            column={column}
            title="Status"
            className="ml-6"
          />
        ),
        cell: ({ row }) => (
          <div className="ml-2 flex items-center">
            <Button
              variant="category"
              size="sm"
              className={
                row.original.status === 'active'
                  ? 'bg-green-200 border-green-500 text-green-800 hover:bg-green-300 focus-visible:ring-0'
                  : row.original.status === 'pendingCreation'
                  ? 'border-amber-500 bg-amber-200 text-amber-800 hover:bg-amber-300 focus-visible:ring-0'
                  : row.original.status === 'pendingUpdating'
                  ? 'border-amber-500 bg-amber-200 text-amber-800 hover:bg-amber-300 focus-visible:ring-0'
                  : row.original.status === 'inactive'
                  ? 'bg-red-200 border-red-500 text-red-800 hover:bg-red-300 focus-visible:ring-0'
                  : ''
              }
            >
              <div className="flex items-center justify-between">
                <span>{row.original.status}</span>
                {/* <ChevronDown className="pl-2 " /> */}
              </div>
            </Button>
          </div>
        ),
      },
      {
        accessorKey: 'title',
        header: ({ column }) => (
          <DataTableColumnHeader column={column} title="Course" />
        ),
        cell: ({ row }) => (
          <span className="font-medium">{row.original.title}</span>
        ),
      },
      {
        accessorKey: 'price',
        header: ({ column }) => (
          <DataTableColumnHeader column={column} title="Price" />
        ),
        cell: ({ row }) => (
          <span className="font-medium">{row.original.price}</span>
        ),
      },
      {
        accessorKey: 'buyersCount',
        header: ({ column }) => (
          <DataTableColumnHeader column={column} title="Sales" />
        ),
        cell: ({ row }) => (
          <span className="font-medium">{row.original.buyersCount}</span>
        ),
      },
      {
        accessorKey: 'createdAt',
        header: ({ column }) => (
          <DataTableColumnHeader column={column} title="Created At" />
        ),
        cell: ({ row }) => (
          <span>{dayjs(row.original.createdAt).format('MMM D, YYYY')}</span>
        ),
      },
      {
        accessorKey: 'updatedAt',
        header: ({ column }) => (
          <DataTableColumnHeader column={column} title="Updated At" />
        ),
        cell: ({ row }) => (
          <span>{dayjs(row.original.updatedAt).format('MMM D, YYYY')}</span>
        ),
      },

      {
        id: 'actions',
        header: () => (
          <span className="hover:text-accent-foreground cursor-pointer text-xs">
            Actions
          </span>
        ),
        cell: ({ row }) => (
          <div className="flex space-x-2">
            <Settings2
              className="cursor-pointer h-8 w-8 border border-grey-300 rounded-md p-[5px]"
              onClick={() => {
                navigate(
                  '/dashboard/courses/instructor/edit/' + row.original.course_id
                );
              }}
            />
            <AlertDialogDemo
              title="Are you absolutely sure?"
              description="This action cannot be undone. This will permanently delete the account and remove the data from our servers."
              action="Delete"
              isDeleting={isDeleting}
              onClick={() => {
                deleteCourse({ course_id: row.original.course_id! })
                  .unwrap()
                  .then((response) => {
                    toast.success(response.message);
                  })
                  .catch((error: any) => {
                    toast.error(
                      error?.data?.message ?? error?.error.toString()
                    );
                  });
              }}
            >
              <Trash2 className="cursor-pointer h-8 w-8 border border-grey-300 rounded-md p-[5px] text-red-500" />
            </AlertDialogDemo>
          </div>
        ),
      },
    ],
    []
  );

  if (isLoading) return <DataTableShimmer columns={4} />;
  if (isError) return <Error fullScreen={false} />;

  return (
    <DataTable<CEMarketCourseI, string>
      columns={columns}
      data={data ?? []}
      totalEntries={data?.length ?? 0}
      isFetching={isFetching}
      selectRows={false}
      title="My-Courses"
      createBtn
      isInst
    />
  );
}
